summaryrefslogtreecommitdiffstats
path: root/plugins/mmnormalize/mmnormalize.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/mmnormalize/mmnormalize.c')
-rw-r--r--plugins/mmnormalize/mmnormalize.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/plugins/mmnormalize/mmnormalize.c b/plugins/mmnormalize/mmnormalize.c
index 8c4efd81..49b143b6 100644
--- a/plugins/mmnormalize/mmnormalize.c
+++ b/plugins/mmnormalize/mmnormalize.c
@@ -64,7 +64,7 @@ typedef struct _instanceData {
} instanceData;
typedef struct configSettings_s {
- uchar *sampdb; /**< name of sample db to use */
+ uchar *rulebase; /**< name of sample db to use */
sbool bUseRawMsg; /**< use %rawmsg% instead of %msg% */
} configSettings_t;
@@ -148,7 +148,7 @@ CODE_STD_STRING_REQUESTparseSelectorAct(1)
ABORT_FINALIZE(RS_RET_CONFLINE_UNPROCESSED);
}
- if(cs.sampdb == NULL) {
+ if(cs.rulebase == NULL) {
errmsg.LogError(0, RS_RET_NO_RULESET, "error: no sample database was specified, use "
"$MMNormalizeSampleDB directive first!");
ABORT_FINALIZE(RS_RET_NO_RULESET);
@@ -180,9 +180,9 @@ CODE_STD_STRING_REQUESTparseSelectorAct(1)
ABORT_FINALIZE(RS_RET_ERR_LIBLOGNORM_INIT);
}
ln_setEECtx(pData->ctxln, pData->ctxee);
- if(ln_loadSamples(pData->ctxln, (char*) cs.sampdb) != 0) {
+ if(ln_loadSamples(pData->ctxln, (char*) cs.rulebase) != 0) {
errmsg.LogError(0, RS_RET_NO_RULESET, "error: sample db '%s' could not be loaded "
- "cannot activate action", cs.sampdb);
+ "cannot activate action", cs.rulebase);
ee_exitCtx(pData->ctxee);
ln_exitCtx(pData->ctxln);
ABORT_FINALIZE(RS_RET_ERR_LIBLOGNORM_SAMPDB_LOAD);
@@ -191,8 +191,8 @@ CODE_STD_STRING_REQUESTparseSelectorAct(1)
/* all config vars auto-reset! */
cs.bUseRawMsg = 0;
- free(cs.sampdb);
- cs.sampdb = NULL;
+ free(cs.rulebase);
+ cs.rulebase = NULL;
CODE_STD_FINALIZERparseSelectorAct
ENDparseSelectorAct
@@ -215,17 +215,17 @@ ENDqueryEtryPt
static rsRetVal resetConfigVariables(uchar __attribute__((unused)) *pp, void __attribute__((unused)) *pVal)
{
DEFiRet;
- cs.sampdb = NULL;
+ cs.rulebase = NULL;
cs.bUseRawMsg = 0;
RETiRet;
}
/* set the sampdb name */
static rsRetVal
-setSampDB(void __attribute__((unused)) *pVal, uchar *pszName)
+setRuleBase(void __attribute__((unused)) *pVal, uchar *pszName)
{
DEFiRet;
- cs.sampdb = pszName;
+ cs.rulebase = pszName;
pszName = NULL;
RETiRet;
}
@@ -261,8 +261,8 @@ CODEmodInit_QueryRegCFSLineHdlr
CHKiRet(objUse(errmsg, CORE_COMPONENT));
- CHKiRet(omsdRegCFSLineHdlr((uchar *)"mmnormalizesampledb", 0, eCmdHdlrGetWord,
- setSampDB, NULL, STD_LOADABLE_MODULE_ID, eConfObjAction));
+ CHKiRet(omsdRegCFSLineHdlr((uchar *)"mmnormalizerulebase", 0, eCmdHdlrGetWord,
+ setRuleBase, NULL, STD_LOADABLE_MODULE_ID, eConfObjAction));
CHKiRet(omsdRegCFSLineHdlr((uchar *)"mmnormalizeuserawmsg", 0, eCmdHdlrInt,
NULL, &cs.bUseRawMsg, STD_LOADABLE_MODULE_ID, eConfObjAction));
CHKiRet(omsdRegCFSLineHdlr((uchar *)"resetconfigvariables", 1, eCmdHdlrCustomHandler,
@@ -215,17 +215,17 @@ ENDqueryEtryPt
RETiRet;
}
-/* set the sampdb name */
+/* set the rulebase name */
static rsRetVal